is_policy_lookup_error

Function is_policy_lookup_error 

pub fn is_policy_lookup_error(e: &TempoPrecompileError) -> bool
Returns true if the error indicates a failed policy lookup — the policy type is invalid or the policy doesn’t exist.