pub struct PolicyData {
pub policy_type: u8,
pub admin: Address,
}Expand description
Base policy metadata. Packed into a single storage slot.
Fields
policy_type: u8Discriminant of the PolicyType enum, stored as u8 for slot packing.
admin: AddressAddress authorized to modify this policy.
Implementations
Sourceimpl PolicyData
impl PolicyData
Sourcepub fn decode_from_slot(slot_value: U256) -> Self
pub fn decode_from_slot(slot_value: U256) -> Self
Decodes a PolicyData from a raw EVM storage slot word.
Sourcepub fn encode_to_slot(&self) -> U256
pub fn encode_to_slot(&self) -> U256
Encodes this PolicyData into a single EVM storage slot word.
Sourcefn policy_type(&self) -> Result<PolicyType>
fn policy_type(&self) -> Result<PolicyType>
Decodes the raw policy_type u8 to a PolicyType enum.
Sourcefn is_simple(&self) -> bool
fn is_simple(&self) -> bool
Returns true if the policy type is a simple policy (WHITELIST or BLACKLIST).
Sourcepub fn is_compound(&self) -> bool
pub fn is_compound(&self) -> bool
Returns true if the policy data indicates a compound policy
Sourcefn is_default(&self) -> bool
fn is_default(&self) -> bool
Returns true if the policy data is the default (uninitialized) value.