pub fn is_policy_lookup_error(e: &TempoPrecompileError) -> boolExpand description
Returns true if the error indicates a failed policy lookup — the policy type is invalid
or the policy doesn’t exist.
pub fn is_policy_lookup_error(e: &TempoPrecompileError) -> boolReturns true if the error indicates a failed policy lookup — the policy type is invalid
or the policy doesn’t exist.